@@ -15,7 +15,8 @@ import napari
 
 print('click to add points; close the window when finished.')
 
-viewer = napari.view_image(data.astronaut(), rgb=True)
+viewer = napari.Viewer()
+layer = viewer.add_image(data.astronaut(), rgb=True)
 points = viewer.add_points(np.zeros((0, 2)))
 points.mode = 'add'
 
