@@ -15,7 +15,8 @@ blobs = data.binary_blobs(
     length=128, blob_size_fraction=0.05, n_dim=2, volume_fraction=0.25
 ).astype(float)
 
-viewer = napari.view_image(blobs, name='blobs')
+viewer = napari.Viewer()
+layer = viewer.add_image(blobs, name='blobs')
 
 
 @viewer.bind_key('a')
