@@ -118,7 +118,8 @@ def create_connected_widget():
 
 if __name__ == '__main__':
 
-    viewer = napari.view_image(np.random.rand(512, 512))
+    viewer = napari.Viewer()
+    layer = viewer.add_image(np.random.rand(512, 512))
     w = create_connected_widget()
     viewer.window.add_dock_widget(w)
 
