@@ -20,6 +20,7 @@ from napari.components.dims import Dims
 from napari.layers import Labels
 from napari.layers.labels._labels_constants import LabelsRendering
 from napari.layers.labels._labels_utils import get_contours
+from napari.layers.labels.labels import WrongSelectedLabelError
 from napari.utils import Colormap
 from napari.utils._test_utils import (
     validate_all_params_in_docstring,
@@ -715,6 +716,14 @@ def test_selecting_label():
     assert len(layer._selected_color) == 4
 
 
+def test_selecting_label_exception():
+    labels = Labels(np.zeros((10, 10), dtype=np.uint8))
+    with pytest.raises(WrongSelectedLabelError, match='The value 256'):
+        labels.selected_label = 256
+    with pytest.raises(WrongSelectedLabelError, match='The value -1'):
+        labels.selected_label = -1
+
+
 def test_label_color():
     """Test getting label color."""
     np.random.seed(0)
